@@ -1,16 +1,17 @@
 # coding=utf-8
 from functools import partial
-import pytest
+
 from mock import Mock
+from pytest import fixture
 
 
-@pytest.fixture(autouse=True)
+@fixture(autouse=True)
 def setup(monkeypatch):
-    from hangman.utils import GameFinished, FlashMessage
+    from hangman.utils import GameOverNotificationComplete, FlashMessage
 
     def draw_board(_, message=FlashMessage()):
-        if message.game_over or message.game_won:
-            raise GameFinished
+        if message.game_lost or message.game_won:
+            raise GameOverNotificationComplete
         return 'View draws board'
 
     monkeypatch.setattr('hangman.view.draw_board', draw_board)
@@ -19,21 +20,21 @@ def setup(monkeypatch):
     monkeypatch.setattr('hangman.view.prompt_play_again', lambda: False)
 
 
-@pytest.fixture(autouse=True)
+@fixture(autouse=True)
 def game():
     from hangman.model import Hangman
 
     return Hangman(answer='hangman')
 
 
-@pytest.fixture
+@fixture
 def flash():
     from hangman.utils import FlashMessage
 
     return FlashMessage()
 
 
-@pytest.fixture
+@fixture
 def run(game, flash):
     from hangman.controller import run
 
@@ -50,13 +51,12 @@ def test_setup():
     assert not view.prompt_play_again()
 
 
-def test_game_over(game, run, monkeypatch, flash):
+def test_game_lost(game, run, monkeypatch, flash):
     monkeypatch.setattr('hangman.view.prompt_guess', lambda: 'O')
     game.misses = list('BCDEFIJKL')
 
     assert run() == 'Have a nice day!'
-    assert flash.game_over is True
-    assert flash.game_answer == 'HANGMAN'
+    assert flash.game_lost is True
 
 
 def test_game_won(game, run, flash):
